@@ -26,6 +26,14 @@ MementoMetaclass = memento_factory("MementoMetaclass",
                                    lambda cls, args, kwargs: (cls, ) + args + tuple(kwargs.items()) )
 
 
+def with_metaclass(meta, base=object):
+    """
+    Create a base class with a metaclass.
+    """
+    if not isinstance(base, tuple):
+        basetuple = (base,)
+    return meta("NewBase", basetuple, {})
+
 # Some reading:
 # http://bytes.com/topic/python/answers/40084-parameterized-metaclass-metametaclass
 # http://www.acooke.org/cute/PythonMeta0.html
